@@ -39,6 +39,7 @@ function(what_sgp_object=NULL,
 	sgp.percentiles.equating.method=NULL,
 	sgp.percentiles.calculate.sgps=TRUE,
 	fix.duplicates=NULL,
+	get.cohort.data.info=FALSE,
 	...) {
 
 	SGPstateData <- SGP::SGPstateData ### Needed due to possible assignment of values to SGPstateData
@@ -78,8 +79,8 @@ function(what_sgp_object=NULL,
 	if (identical(calculate.simex.baseline, TRUE)) {
 		##  Enforce that simex.use.my.coefficient.matrices must be TRUE for updating BASELINE SIMEX SGPs
 		if (is.character(csem.variable <- SGPstateData[[state]][["Assessment_Program_Information"]][["CSEM"]])) {
-			calculate.simex.baseline <- list(csem.data.vnames=csem.variable, lambda=seq(0,2,0.5), simulation.iterations=75, simex.sample.size=5000, extrapolation="linear", save.matrices=TRUE, simex.use.my.coefficient.matrices = TRUE)
-		} else 	calculate.simex.baseline <- list(state=state, lambda=seq(0,2,0.5), simulation.iterations=75, simex.sample.size=5000, extrapolation="linear", save.matrices=TRUE, simex.use.my.coefficient.matrices = TRUE)
+			calculate.simex.baseline <- list(csem.data.vnames=csem.variable, lambda=seq(0,2,0.5), simulation.iterations=75, simex.sample.size=5000, extrapolation="linear", save.matrices=TRUE, simex.use.my.coefficient.matrices = TRUE, use.cohort.for.ranking=TRUE)
+		} else 	calculate.simex.baseline <- list(state=state, lambda=seq(0,2,0.5), simulation.iterations=75, simex.sample.size=5000, extrapolation="linear", save.matrices=TRUE, simex.use.my.coefficient.matrices = TRUE, use.cohort.for.ranking=TRUE)
 	}
 
 	if (is.null(save.old.summaries) && overwrite.existing.data) save.old.summaries <- FALSE else save.old.summaries <- TRUE
@@ -185,6 +186,7 @@ function(what_sgp_object=NULL,
 					sgp.percentiles.calculate.sgps=sgp.percentiles.calculate.sgps,
 					parallel.config=parallel.config,
 					fix.duplicates=fix.duplicates,
+					get.cohort.data.info=get.cohort.data.info,
 					...
 					)
 
@@ -268,6 +270,7 @@ function(what_sgp_object=NULL,
 						sgp.percentiles.calculate.sgps=sgp.percentiles.calculate.sgps,
 						parallel.config=parallel.config,
 						fix.duplicates=fix.duplicates,
+						get.cohort.data.info=get.cohort.data.info,
 						...)
 
 			### Print finish and return SGP object
@@ -318,6 +321,7 @@ function(what_sgp_object=NULL,
 							sgp.percentiles.calculate.sgps=sgp.percentiles.calculate.sgps,
 							parallel.config=parallel.config,
 							fix.duplicates=fix.duplicates,
+							get.cohort.data.info=get.cohort.data.info,
 							...)
 
 				if ("combineSGP" %in% steps) {
@@ -483,6 +487,7 @@ function(what_sgp_object=NULL,
 							sgp.percentiles.calculate.sgps=sgp.percentiles.calculate.sgps,
 							parallel.config=parallel.config,
 							fix.duplicates=fix.duplicates,
+							get.cohort.data.info=get.cohort.data.info,
 							...)
 
 				### Print finish and return SGP object
